#include "configFile.hpp"
#include <sstream>

Config cf::openConfig() {
  std::ifstream file;
  file.open(cf::g_configFile);
  if (file.is_open()) {
    std::string line;
    line = cf::getLine(&file);
    if (line == "") {
      return Config(0, "");
    }
    int8_t numHilos = std::stoi(line);
    std::string tiempo = cf::getLine(&file);
    if (tiempo == "") {
      return Config(0, "");
    }
    file.close();
    return Config(numHilos, tiempo);
  } else {
    return Config(0, "");
  }
}

void cf::closeConfig(Config *config) { delete config; }

std::string cf::getLine(std::ifstream *file) {
  std::string line;
  if (file->peek() != EOF) {
    std::getline(*file, line);

    // Mientras se leen las lineas se comprueban que no estén vacias
    // o sean comentarios de manera que se devuelva el primera línea
    // correcta. De esta manera se puede cambiar el documento añadiendo
    // cuantos comentarios o líneas vacias se desee y dinámicamente se
    // buscará la línea deseada.

    if (line[0] == '#' || line == "") {
      return cf::getLine(file);
    }

    line = line.substr(line.find("= ") + 1, line.length());
    return line;
  } else {
    return "";
  }
}

void cf::saveConfig(Config *config) {
  std::ofstream file(g_configFile);
  file << "#######################################################################" << std::endl;
  file << "# +                    +                     +         +              #" << std::endl;
  file << "#                                 +                  +           +    #" << std::endl;
  file << "#          +                                             +            #" << std::endl;
  file << "#                                       \\ /                           #" << std::endl;
  file << "#                      +     _        - _+_ -                    ___  #" << std::endl;
  file << "#        _=.    .:.         /=\\       _|===|_                  || ::| #" << std::endl;
  file << "#       |  |    _|.        |   |     | |   | |     __===_  -=- || ::| #" << std::endl;
  file << "#       |==|   |  |  __    |.:.|   /\\| | :.| |    |   | .|| : ||| ::| #" << std::endl;
  file << "#       |  |-  |.:|_|. :__ |.: |--|==| |  .| |_   | . |. ||.  ||| :.| #" << std::endl;
  file << "#     __|. | |_|. | |.|...||---|  |==| |   | | |_--.     ||   |||.  | #" << std::endl;
  file << "#    |  |  |   |. | | |::.|| :.|  |==| | . : |=|===|    :|| . |||  .| #" << std::endl;
  file << "#    |:.| .|   |  | | |:.:|| . |  |==| |     |=|===| .   |    | |   | #" << std::endl;
  file << "#    |     |      |   |   |            :   .   |   ;     ;          | #" << std::endl;
  file << "#          :          :                .          .      .          : #" << std::endl;
  file << "#                                                                     #" << std::endl;
  file << "# Archivo autogenerado por Stress_UI                                  #" << std::endl;
  file << "# No editar manualmente sin saber lo que se hace                      #" << std::endl;
  file << "#######################################################################" << std::endl;
  file << std::endl;
  file << "Número de hilos\t\t= " << std::to_string(config->getNumHilos());
  file << std::endl;
  file << "Tiempo de ejecución\t= " << config->getTiempo();
  file.close();
}
